@@ -23,6 +23,7 @@ This module contains Azure Data Explorer hook.
     KustoResponseDataSetV
     kusto
 """
+
 from __future__ import annotations
 
 import warnings
@@ -32,7 +33,7 @@ from typing import TYPE_CHECKING, Any
 from azure.kusto.data import ClientRequestProperties, KustoClient, KustoConnectionStringBuilder
 from azure.kusto.data.exceptions import KustoServiceError
 
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
+from airflow.exceptions import AirflowException
 from airflow.hooks.base import BaseHook
 from airflow.providers.microsoft.azure.utils import (
     add_managed_identity_connection_widgets,
@@ -45,7 +46,7 @@ if TYPE_CHECKING:
 
 class AzureDataExplorerHook(BaseHook):
     """
-    Interacts with Azure Data Explorer (Kusto).
+    Interact with Azure Data Explorer (Kusto).
 
     **Cluster**:
 
@@ -85,7 +86,7 @@ class AzureDataExplorerHook(BaseHook):
     @classmethod
     @add_managed_identity_connection_widgets
     def get_connection_form_widgets(cls) -> dict[str, Any]:
-        """Returns connection widgets to add to connection form."""
+        """Return connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3PasswordFieldWidget, BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import PasswordField, StringField
@@ -103,7 +104,7 @@ class AzureDataExplorerHook(BaseHook):
 
     @classmethod
     def get_ui_field_behaviour(cls) -> dict[str, Any]:
-        """Returns custom field behaviour."""
+        """Return custom field behaviour."""
         return {
             "hidden_fields": ["schema", "port", "extra"],
             "relabeling": {
@@ -160,14 +161,6 @@ class AzureDataExplorerHook(BaseHook):
             value = extras.get(name)
             if value:
                 warn_if_collison(name, backcompat_key)
-            if not value and extras.get(backcompat_key):
-                warnings.warn(
-                    f"`{backcompat_key}` is deprecated in azure connection extra,"
-                    f" please use `{name}` instead",
-                    AirflowProviderDeprecationWarning,
-                    stacklevel=2,
-                )
-                value = extras.get(backcompat_key)
             if not value:
                 raise AirflowException(f"Required connection parameter is missing: `{name}`")
             return value
