@@ -213,7 +213,8 @@ class WasbHook(BaseHook):
             **extra,
         )
 
-    def _get_container_client(self, container_name: str) -> ContainerClient:
+    # TODO: rework the interface as it might also return AsyncContainerClient
+    def _get_container_client(self, container_name: str) -> ContainerClient:  # type: ignore[override]
         """
         Instantiate a container client.
 
@@ -222,7 +223,7 @@ class WasbHook(BaseHook):
         """
         return self.blob_service_client.get_container_client(container_name)
 
-    def _get_blob_client(self, container_name: str, blob_name: str) -> BlobClient:
+    def _get_blob_client(self, container_name: str, blob_name: str) -> BlobClient | AsyncBlobClient:
         """
         Instantiate a blob client.
 
@@ -415,7 +416,8 @@ class WasbHook(BaseHook):
             self.create_container(container_name)
 
         blob_client = self._get_blob_client(container_name, blob_name)
-        return blob_client.upload_blob(data, blob_type, length=length, **kwargs)
+        # TODO: rework the interface as it might also return Awaitable
+        return blob_client.upload_blob(data, blob_type, length=length, **kwargs)  # type: ignore[return-value]
 
     def download(
         self, container_name, blob_name, offset: int | None = None, length: int | None = None, **kwargs
@@ -430,7 +432,8 @@ class WasbHook(BaseHook):
         :param length: Number of bytes to read from the stream.
         """
         blob_client = self._get_blob_client(container_name, blob_name)
-        return blob_client.download_blob(offset=offset, length=length, **kwargs)
+        # TODO: rework the interface as it might also return Awaitable
+        return blob_client.download_blob(offset=offset, length=length, **kwargs)  # type: ignore[return-value]
 
     def create_container(self, container_name: str) -> None:
         """
@@ -490,6 +493,33 @@ class WasbHook(BaseHook):
         self._get_container_client(container_name).delete_blobs(*blobs, **kwargs)
         self.log.info("Deleted blobs: %s", blobs)
 
+    def copy_blobs(
+        self,
+        source_container_name: str,
+        source_blob_name: str,
+        destination_container_name: str,
+        destination_blob_name: str,
+    ) -> None:
+        """
+        Copy the specified blobs from one blob prefix to another.
+
+        :param source_container_name: The name of the source container containing the blobs.
+        :param source_blob_name: The full source blob path without the container name.
+        :param destination_container_name: The name of the destination container where the blobs
+            will be copied to.
+        :param destination_blob_name: The full destination blob path without the container name.
+        """
+        source_blob_client = self._get_blob_client(
+            container_name=source_container_name, blob_name=source_blob_name
+        )
+        source_blob_url = source_blob_client.url
+
+        destination_blob_client = self._get_blob_client(
+            container_name=destination_container_name, blob_name=destination_blob_name
+        )
+
+        destination_blob_client.start_copy_from_url(source_blob_url)
+
     def delete_file(
         self,
         container_name: str,
@@ -656,7 +686,8 @@ class WasbAsyncHook(WasbHook):
             return False
         return True
 
-    def _get_container_client(self, container_name: str) -> AsyncContainerClient:
+    # TODO: rework the interface as in parent Hook it returns ContainerClient
+    def _get_container_client(self, container_name: str) -> AsyncContainerClient:  # type: ignore[override]
         """
         Instantiate a container client.
 
