@@ -19,12 +19,10 @@ from __future__ import annotations
 
 import asyncio
 import time
-from typing import TYPE_CHECKING, AsyncIterator
+from collections.abc import AsyncIterator
+from typing import TYPE_CHECKING
 
-from airflow.providers.microsoft.azure.hooks.powerbi import (
-    PowerBIDatasetRefreshStatus,
-    PowerBIHook,
-)
+from airflow.providers.microsoft.azure.hooks.powerbi import PowerBIDatasetRefreshStatus, PowerBIHook
 from airflow.triggers.base import BaseTrigger, TriggerEvent
 
 if TYPE_CHECKING:
@@ -105,35 +103,37 @@ class PowerBITrigger(BaseTrigger):
             group_id=self.group_id,
         )
 
-        async def fetch_refresh_status() -> str:
-            """Fetch the current status of the dataset refresh."""
+        async def fetch_refresh_status_and_error() -> tuple[str, str]:
+            """Fetch the current status and error of the dataset refresh."""
             refresh_details = await self.hook.get_refresh_details_by_refresh_id(
                 dataset_id=self.dataset_id,
                 group_id=self.group_id,
                 refresh_id=self.dataset_refresh_id,
             )
-            return refresh_details["status"]
+            return refresh_details["status"], refresh_details["error"]
 
         try:
-            dataset_refresh_status = await fetch_refresh_status()
+            dataset_refresh_status, dataset_refresh_error = await fetch_refresh_status_and_error()
             start_time = time.monotonic()
             while start_time + self.timeout > time.monotonic():
-                dataset_refresh_status = await fetch_refresh_status()
+                dataset_refresh_status, dataset_refresh_error = await fetch_refresh_status_and_error()
 
                 if dataset_refresh_status == PowerBIDatasetRefreshStatus.COMPLETED:
                     yield TriggerEvent(
                         {
-                            "status": dataset_refresh_status,
+                            "status": "success",
+                            "dataset_refresh_status": dataset_refresh_status,
                             "message": f"The dataset refresh {self.dataset_refresh_id} has {dataset_refresh_status}.",
                             "dataset_refresh_id": self.dataset_refresh_id,
                         }
                     )
                     return
-                elif dataset_refresh_status == PowerBIDatasetRefreshStatus.FAILED:
+                elif dataset_refresh_status in PowerBIDatasetRefreshStatus.FAILURE_STATUSES:
                     yield TriggerEvent(
                         {
-                            "status": dataset_refresh_status,
-                            "message": f"The dataset refresh {self.dataset_refresh_id} has {dataset_refresh_status}.",
+                            "status": "error",
+                            "dataset_refresh_status": dataset_refresh_status,
+                            "message": f"The dataset refresh {self.dataset_refresh_id} has {dataset_refresh_status}. Error: {dataset_refresh_error}",
                             "dataset_refresh_id": self.dataset_refresh_id,
                         }
                     )
@@ -149,6 +149,7 @@ class PowerBITrigger(BaseTrigger):
             yield TriggerEvent(
                 {
                     "status": "error",
+                    "dataset_refresh_status": dataset_refresh_status,
                     "message": f"Timeout occurred while waiting for dataset refresh to complete: The dataset refresh {self.dataset_refresh_id} has status {dataset_refresh_status}.",
                     "dataset_refresh_id": self.dataset_refresh_id,
                 }
@@ -171,6 +172,7 @@ class PowerBITrigger(BaseTrigger):
                     yield TriggerEvent(
                         {
                             "status": "error",
+                            "dataset_refresh_status": None,
                             "message": f"An error occurred while canceling dataset: {e}",
                             "dataset_refresh_id": self.dataset_refresh_id,
                         }
@@ -179,6 +181,7 @@ class PowerBITrigger(BaseTrigger):
             yield TriggerEvent(
                 {
                     "status": "error",
+                    "dataset_refresh_status": None,
                     "message": f"An error occurred: {error}",
                     "dataset_refresh_id": self.dataset_refresh_id,
                 }
